<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * Support Tickets
 *
 * A simple, yet powerful support tickets system
 *
 * @package MailWizz EMA
 * @subpackage Support Tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com>
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */

class SupportTicketsExt extends ExtensionInit
{
    // name of the extension as shown in the backend panel
    public $name = 'Support Tickets';

    // description of the extension as shown in backend panel
    public $description = 'A simple, yet powerful support tickets system';

    // current version of this extension
    public $version = '1.1';

    // minimum app version required for this extension to run properly
    public $minAppVersion = '1.3.4.5';

    // the author name
    public $author = 'Cristian Serban';

    // author website
    public $website = 'http://www.mailwizz.com/';

    // contact email address
    public $email = 'cristian.serban@mailwizz.com';

    // in which apps this extension is allowed to run
    public $allowedApps = array('backend', 'console', 'customer');

    // mark as cli enabled.
    public $cliEnabled = true;

    // can this extension be deleted? this only applies to core extensions.
    protected $_canBeDeleted = true;

    // can this extension be disabled? this only applies to core extensions.
    protected $_canBeDisabled = true;

    // the extension model
    protected $_extModel;

    // run the extension
    public function run()
    {
        Yii::import('ext-support-tickets.common.models.*');

        if ($this->isAppName('backend')) {

            // handle all backend related tasks
            $this->backendApp();

        } elseif ($this->isAppName('console')) {

            // handle all console related tasks
            $this->consoleApp();

        } elseif ($this->isAppName('customer')) {

            // handle all customer related tasks
            $this->customerApp();
        }
    }

    // Add the landing page for this extension (settings/general info/etc)
    public function getPageUrl()
    {
        return Yii::app()->createUrl('support_tickets_ext/settings');
    }

    // create the database tables
    public function beforeEnable()
    {
        if (!$this->runQueriesFromSqlFile('install')) {
            return false;
        }
        return true;
    }

    // drop the tables
    public function beforeDelete()
    {
        if (!$this->runQueriesFromSqlFile('delete')) {
            return false;
        }
        return true;
    }

    // handle all backend related tasks
    protected function backendApp()
    {
        $hooks = Yii::app()->hooks;

        // register the url rule(s) to resolve the extension page(s).
        Yii::app()->urlManager->addRules(array(
            array('support_tickets_ext_departments/<action>', 'pattern' => 'support-tickets/departments/<action>/*'),
            array('support_tickets_ext_departments/<action>', 'pattern' => 'support-tickets/departments/<action>'),
            array('support_tickets_ext_priorities/<action>', 'pattern' => 'support-tickets/priorities/<action>/*'),
            array('support_tickets_ext_priorities/<action>', 'pattern' => 'support-tickets/priorities/<action>'),
            array('support_tickets_ext/<action>', 'pattern' => 'support-tickets/<action>/*'),
            array('support_tickets_ext/<action>', 'pattern' => 'support-tickets/<action>'),
        ));

        // add the controllers
        Yii::app()->controllerMap['support_tickets_ext'] = array(
            'class'     => 'ext-support-tickets.backend.controllers.Support_tickets_extController',
            'extension' => $this,
        );
        Yii::app()->controllerMap['support_tickets_ext_departments'] = array(
            'class'     => 'ext-support-tickets.backend.controllers.Support_tickets_ext_departmentsController',
            'extension' => $this,
        );
        Yii::app()->controllerMap['support_tickets_ext_priorities'] = array(
            'class'     => 'ext-support-tickets.backend.controllers.Support_tickets_ext_prioritiesController',
            'extension' => $this,
        );

        // add the menu item
        $hooks->addFilter('backend_left_navigation_menu_items', array($this, '_registerBackendMenuItem'));
    }

    // handle all console related tasks
    protected function consoleApp()
    {
        $hooks = Yii::app()->hooks;
        $hooks->addAction('console_command_daily', array($this, '_consoleCloseInactiveTickets'));
    }

    // handle all customer related tasks
    protected function customerApp()
    {
        $hooks = Yii::app()->hooks;

        // register the hook to check controller access
        $hooks->addAction('customer_controller_support_tickets_ext_init', array($this, '_checkCustomerAccess'));

        // register the url rule(s) to resolve the extension page(s).
        Yii::app()->urlManager->addRules(array(
            array('support_tickets_ext/<action>', 'pattern' => 'support-tickets/<action>/*'),
            array('support_tickets_ext/<action>', 'pattern' => 'support-tickets/<action>'),
        ));

        // add the controller
        Yii::app()->controllerMap['support_tickets_ext'] = array(
            'class'     => 'ext-support-tickets.customer.controllers.Support_tickets_extController',
            'extension' => $this,
        );

        // add the menu item
        $hooks->addFilter('customer_left_navigation_menu_items', array($this, '_registerCustomerMenuItem'));
    }

    protected function runQueriesFromSqlFile($fileName)
    {
        if (!is_file($sqlFile = dirname(__FILE__) . sprintf('/common/data/sql/%s.sql', $fileName))) {
            return false;
        }

        $queries = (array)CommonHelper::getQueriesFromSqlFile($sqlFile, Yii::app()->getDb()->tablePrefix);

        foreach ($queries as $query) {
            Yii::app()->getDb()->createCommand($query)->execute();
        }

        return true;
    }

    // extension main model
    public function getExtModel()
    {
        if ($this->_extModel !== null) {
            return $this->_extModel;
        }

        $this->_extModel = new SupportTicketsExtModel();
        return $this->_extModel->setExtensionInstance($this)->populate();
    }

    // backend menu callback
    public function _registerBackendMenuItem($items)
    {
        $route          = Yii::app()->getController()->getRoute();
        $spActions      = array('index', 'create', 'update', 'view');
        $spActionActive = false;

        foreach ($spActions as $action) {
            if (strpos($route, 'support_tickets_ext/' . $action) === 0) {
                $spActionActive = true;
                break;
            }
        }

        $item = array(
            'name'   => Yii::t('ext_support_tickets', 'Support tickets'),
            'icon'   => 'glyphicon-book',
            'active' => 'support_tickets_ext',
            'route'  => null,
            'items'  => array(
                array('url' => array('support_tickets_ext/index'), 'label' => Yii::t('ext_support_tickets', 'Support tickets'), 'active' => $spActionActive),
                array('url' => array('support_tickets_ext_departments/index'), 'label' => Yii::t('ext_support_tickets', 'Departments'), 'active' => strpos($route, 'support_tickets_ext_departments') === 0),
                array('url' => array('support_tickets_ext_priorities/index'), 'label' => Yii::t('ext_support_tickets', 'Priorities'), 'active' => strpos($route, 'support_tickets_ext_priorities') === 0),
                array('url' => array('support_tickets_ext/settings'), 'label' => Yii::t('app', 'Settings'), 'active' => strpos($route, 'support_tickets_ext/settings') === 0),
            ),
        );

        $newItems = array();
        foreach ($items as $id => $data) {
            if ($id == 'locations') {
                $newItems['support-tickets'] = $item;
            }
            $newItems[$id] = $data;
        }

        if (!isset($newItems['support-tickets'])) {
            $newItems['support-tickets'] = $item;
        }

        return $newItems;
    }

    // customer menu callback
    public function _registerCustomerMenuItem($items)
    {
        if (!$this->getCustomerAllowed()) {
            return $items;
        }

        $route = Yii::app()->getController()->getRoute();

        $items['support-tickets'] = array(
            'name'   => Yii::t('ext_support_tickets', 'Support tickets'),
            'icon'   => 'glyphicon-book',
            'active' => 'support_tickets_ext',
            'route'  => array('support_tickets_ext/index'),
        );

        return $items;
    }

    // callback for daily command to close inactive tickets
    public function _consoleCloseInactiveTickets($command)
    {
        // because FormModel is not defined in console
        $days = (int)Yii::app()->options->get('system.extension.support-tickets.data.inactive_close_days', 3);
        $sql  = sprintf('UPDATE {{support_ticket}} SET `status` = :st WHERE `status` != :st AND DATE(last_updated) < DATE(DATE_SUB(NOW(), INTERVAL %d DAY))', $days);
		Yii::app()->getDb()->createCommand($sql)->execute(array(':st' => SupportTicket::STATUS_CLOSED));
    }

    // callback to check customer access to controller(s)
    public function _checkCustomerAccess()
    {
        if (!$this->getCustomerAllowed()) {
            Yii::app()->getController()->redirect(array('dashboard/index'));
        }
    }

    // helper method to see if the customer is allowed to access the page(s)
    public function getCustomerAllowed()
    {
        if (Yii::app()->customer->getIsGuest()) {
            return false;
        }

        if (count($this->getExtModel()->groups) && !in_array(Yii::app()->customer->getModel()->group_id, $this->getExtModel()->groups)) {
            return false;
        }

        return true;
    }
}
