<?php defined('MW_PATH') || exit('No direct script access allowed');

/** 
 * Controller file.
 * 
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */
 
class Support_tickets_extController extends Controller
{
    // the extension instance
    public $extension;
    
    public function init()
    {
        $this->onBeforeAction = array($this, '_handleAssetsRegistration');
        parent::init();
    }
    
    // the filters
    public function filters()
    {
        $filters = array(
            'postOnly + delete, delete_reply',
        );
        
        return CMap::mergeArray($filters, parent::filters());
    }
    
    // move the view path
    public function getViewPath()
    {
        return Yii::getPathOfAlias('ext-support-tickets.backend.views.support-tickets');
    }
    
    public function actionIndex()
    {
        $request = Yii::app()->request;
        $ticket  = new SupportTicket('search');
        
        $ticket->unsetAttributes();
        $ticket->attributes = (array)$request->getQuery($ticket->modelName, array());
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                Yii::t('ext_support_tickets', 'View all'),
            )
        ));

        $this->render('list', compact('ticket'));
    }
    
    public function actionCreate()
    {
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        $options = Yii::app()->options;
        $ticket  = new SupportTicket();

        if ($request->isPostRequest && ($attributes = (array)$request->getPost($ticket->modelName, array()))) {
            $ticket->attributes = $attributes;
            $ticket->content    = Yii::app()->ioFilter->purify(Yii::app()->params['POST'][$ticket->modelName]['content']);
            $ticket->user_id    = Yii::app()->user->getId();
            $ticket->ip_address = $request->getUserHostAddress();

            if (!$ticket->save()) {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            } else {
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
                
                // send email to customer
                $emailTemplate  = $options->get('system.email_templates.common');
                $emailBody      = $this->renderPartial('emails/_ticket-to-customer', compact('ticket'), true);
                $emailTemplate  = str_replace('[CONTENT]', $emailBody, $emailTemplate);
                
                $email = new TransactionalEmail();
                $email->to_name   = $ticket->customer->getFullName();
                $email->to_email  = $ticket->customer->email;
                $email->from_name = Yii::t('ext_support_tickets', '{site} support', array('{site}' => $options->get('system.common.site_name', 'Marketing website')));
                $email->subject   = Yii::t('ext_support_tickets', '[{site} support] {subject}', array(
                    '{site}'    => $options->get('system.common.site_name', 'Marketing website'),
                    '{subject}' => $ticket->subject,
                ));
                $email->body      = $emailTemplate;
                $email->save();
            }
            
            Yii::app()->hooks->doAction('controller_action_save_data', $collection = new CAttributeCollection(array(
                'controller'=> $this,
                'success'   => $notify->hasSuccess,
                'ticket'    => $ticket,
            )));
            
            if ($collection->success) {
                $this->redirect(array($this->id . '/index'));
            }
        }
        
        $ticket->fieldDecorator->onHtmlOptionsSetup = array($this, '_setupEditorOptions');
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                Yii::t('app', 'Create new'),
            )
        ));

        $this->render('form', compact('ticket'));
    }
    
    public function actionUpdate($id)
    {
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        $ticket  = SupportTicket::model()->findByPk((int)$id);
        
        if (empty($ticket)) {
            throw new CHttpException(404, Yii::t('app', 'The requested page does not exist.'));
        }
        
        if ($request->isPostRequest && ($attributes = (array)$request->getPost($ticket->modelName, array()))) {
            $ticket->attributes = $attributes;
            $ticket->content    = Yii::app()->ioFilter->purify(Yii::app()->params['POST'][$ticket->modelName]['content']);
            $ticket->user_id    = Yii::app()->user->getId();

            if (!$ticket->save()) {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            } else {
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
            }
            
            Yii::app()->hooks->doAction('controller_action_save_data', $collection = new CAttributeCollection(array(
                'controller'=> $this,
                'success'   => $notify->hasSuccess,
                'ticket'    => $ticket,
            )));
            
            if ($collection->success) {
                $this->redirect(array($this->id . '/index'));
            }
        }
        
        $ticket->fieldDecorator->onHtmlOptionsSetup = array($this, '_setupEditorOptions');
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                Yii::t('app', 'Create new'),
            )
        ));

        $this->render('form', compact('ticket'));
    }
    
    public function actionDelete($id)
    {
        $ticket = SupportTicket::model()->findByPk((int)$id);
        if (empty($ticket)) {
            throw new CHttpException(404, Yii::t('app', 'The requested page does not exist.'));
        }
        
        $ticket->delete();
        
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        
        if (!$request->getQuery('ajax')) {
            $notify->addSuccess(Yii::t('app', 'The item has been successfully deleted!'));
            $this->redirect($request->getPost('returnUrl', array($this->id . '/index')));
        }
    }
    
    public function actionView($id)
    {
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        $options = Yii::app()->options;
        $ticket  = SupportTicket::model()->findByPk((int)$id);
        $reply   = new SupportTicketReply();
        
        if (empty($ticket)) {
            throw new CHttpException(404, Yii::t('app', 'The requested page does not exist.'));
        }
        
        if (empty($ticket->user_id)) {
            $ticket->user_id = Yii::app()->user->getId();
            $ticket->save(false);
        }
        
        if ($ticket->user_id != Yii::app()->user->getId()) {
            $notify->addInfo(Yii::t('ext_support_tickets', 'This ticket has been assigned to {user} already, replying to it will assign you to the ticket.', array('{user}' => $ticket->user->fullName)));
        }
        
        if ($request->isPostRequest && ($attributes = (array)$request->getPost($reply->modelName, array()))) {
            $reply->attributes = $attributes;
            $reply->content    = Yii::app()->ioFilter->purify(Yii::app()->params['POST'][$reply->modelName]['content']);
            $reply->ticket_id  = $ticket->ticket_id;
            $reply->user_id    = Yii::app()->user->getId();
            $reply->ip_address = $request->getUserHostAddress();
            
            if (!$reply->save()) {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            } else {
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
                $ticket->user_id = Yii::app()->user->getId();
                $ticket->status  = SupportTicket::STATUS_WAITING_CUSTOMER_REPLY;

                if ($reply->after_save_action == SupportTicketReply::AFTER_SAVE_ACTION_CLOSE_SEND || 
                    $reply->after_save_action == SupportTicketReply::AFTER_SAVE_ACTION_CLOSE_DONT_SEND) {
                    $ticket->status = SupportTicket::STATUS_CLOSED;
                }
                
                $ticket->save(false);
                
                $sendEmail = true;
                if ($reply->after_save_action == SupportTicketReply::AFTER_SAVE_ACTION_CLOSE_DONT_SEND) {
                    $sendEmail = false;
                }
                
                if ($sendEmail) {
                    // send email to customer
                    $emailTemplate = $options->get('system.email_templates.common');
                    $emailBody     = $this->renderPartial('emails/_reply-to-customer', compact('ticket', 'reply'), true);
                    $emailTemplate = str_replace('[CONTENT]', $emailBody, $emailTemplate);
                    
                    $email = new TransactionalEmail();
                    $email->to_name   = $ticket->customer->getFullName();
                    $email->to_email  = $ticket->customer->email;
                    $email->from_name = Yii::t('ext_support_tickets', '{site} support', array('{site}' => $options->get('system.common.site_name', 'Marketing website')));
                    $email->subject   = Yii::t('ext_support_tickets', '[{site} support] {subject}', array(
                        '{site}'    => $options->get('system.common.site_name', 'Marketing website'),
                        '{subject}' => $ticket->subject,
                    ));
                    $email->body      = $emailTemplate;
                    $email->save();    
                }
            }
            
            Yii::app()->hooks->doAction('controller_action_save_data', $collection = new CAttributeCollection(array(
                'controller'=> $this,
                'success'   => $notify->hasSuccess,
                'ticket'    => $ticket,
                'reply'     => $reply,
            )));
            
            if ($collection->success) {
                $this->redirect($this->createUrl($this->id . '/view', array('id' => $ticket->ticket_id)) . '#reply-' . $reply->reply_id);
            }
        }
        
        $reply->fieldDecorator->onHtmlOptionsSetup = array($this, '_setupEditorOptions');
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'View support ticket'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'View support ticket'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                sprintf('#%d', $id)  => $this->createUrl($this->id . '/update', array('id' => $id)),
                Yii::t('app', 'View'),
            )
        ));

        $this->render('view', compact('ticket', 'reply'));
    }
    
    public function actionDelete_reply($id)
    {
        $reply = SupportTicketReply::model()->findByPk((int)$id);
        if (empty($reply)) {
            throw new CHttpException(404, Yii::t('app', 'The requested page does not exist.'));
        }
        
        $reply->delete();
        
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        
        if (!$request->getQuery('ajax')) {
            $notify->addSuccess(Yii::t('app', 'The item has been successfully deleted!'));
            $this->redirect($request->getPost('returnUrl', array($this->id . '/index')));
        }
    }
    
    public function actionSettings()
    {
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        $model   = $this->extension->getExtModel();

        if ($request->isPostRequest && ($attributes = (array)$request->getPost($model->modelName, array()))) {
            if (empty($attributes['groups'])) {
                $attributes['groups'] = array();
            }
            $model->attributes = $attributes;
            if ($model->validate()) {
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
                $model->save();
            } else {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            }
        }
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets settings'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets settings'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                Yii::t('ext_support_tickets', 'Settings'),
            )
        ));

        $this->render('settings', compact('model'));
    }
    
    /**
     * Callback to register assets
     */
    public function _handleAssetsRegistration($event)
    {
        if (in_array($event->params['action']->id, array('create', 'update'))) {
            $this->getData('pageStyles')->mergeWith(array(
                array('src' => Yii::app()->apps->getBaseUrl('assets/css/jui-bs/jquery-ui-1.10.3.custom.css'), 'priority' => -1001),
            ));
        }
        
        if (in_array($event->params['action']->id, array('view'))) {
            $commonAssetsUrl = Yii::app()->assetManager->publish(Yii::getPathOfAlias('ext-support-tickets.common.assets'), false, -1, MW_DEBUG);
            $assetsUrl       = Yii::app()->assetManager->publish(Yii::getPathOfAlias('ext-support-tickets.backend.assets'), false, -1, MW_DEBUG);
            $this->getData('pageStyles')->mergeWith(array(
                array('src' => $commonAssetsUrl . '/css/support-tickets.css'),
            ));
            $this->getData('pageScripts')->mergeWith(array(
                array('src' => $assetsUrl . '/js/support-tickets.js'),
            ));
        }
    }
    
    /**
     * Callback method to set the editor options
     */
    public function _setupEditorOptions(CEvent $event)
    {
        if (!in_array($event->params['attribute'], array('content'))) {
            return;
        }
        
        $options = array();
        if ($event->params['htmlOptions']->contains('wysiwyg_editor_options')) {
            $options = (array)$event->params['htmlOptions']->itemAt('wysiwyg_editor_options');
        }
        $options['id']     = CHtml::activeId($event->sender->owner, $event->params['attribute']);
        $options['height'] = 400;
        
        if ($event->sender->owner instanceof SupportTicketReply) {
            $options['height'] = 200;
        }
        
        $event->params['htmlOptions']->add('wysiwyg_editor_options', $options);
    }
}