<?php defined('MW_PATH') || exit('No direct script access allowed');

/** 
 * Controller file.
 * 
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */
 
class Support_tickets_ext_departmentsController extends Controller
{
    // the extension instance
    public $extension;
    
    // the filters
    public function filters()
    {
        $filters = array(
            'postOnly + delete',
        );
        
        return CMap::mergeArray($filters, parent::filters());
    }
    
    // move the view path
    public function getViewPath()
    {
        return Yii::getPathOfAlias('ext-support-tickets.backend.views.departments');
    }
    
    public function actionIndex()
    {
        $request = Yii::app()->request;
        $model   = new SupportTicketDepartment('search');
        
        $model->unsetAttributes();
        $model->attributes = (array)$request->getQuery($model->modelName, array());
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets departments'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets departments'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl('support_tickets_ext/index'),
                Yii::t('ext_support_tickets', 'Departments')  => $this->createUrl($this->id . '/index'),
                Yii::t('app', 'View all'),
            )
        ));

        $this->render('list', compact('model'));
    }
    
    public function actionCreate()
    {
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        $model   = new SupportTicketDepartment();
        
        $userToDepartment = new UserToSupportTicketDepartment();
        
        if ($request->isPostRequest && ($attributes = (array)$request->getPost($model->modelName, array()))) {
            $model->attributes = $attributes;
            if (!$model->save()) {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            } else {
                if ($assignedUsers = (array)$request->getPost($userToDepartment->modelName, array())) {
                    $assignedUsers = array_map('intval', $assignedUsers);
                    foreach ($assignedUsers as $userId) {
                        $assign = new UserToSupportTicketDepartment();
                        $assign->user_id       = $userId;
                        $assign->department_id = $model->department_id;
                        $assign->save();
                    }
                }
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
            }
            
            Yii::app()->hooks->doAction('controller_action_save_data', $collection = new CAttributeCollection(array(
                'controller'=> $this,
                'success'   => $notify->hasSuccess,
                'model'     => $model,
            )));
            
            if ($collection->success) {
                $this->redirect(array($this->id . '/index'));
            }
        }

        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets departments'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets departments'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl('support_tickets_ext/index'),
                Yii::t('ext_support_tickets', 'Departments')  => $this->createUrl($this->id . '/index'),
                Yii::t('app', 'Create new'),
            )
        ));

        $this->render('form', compact('model', 'userToDepartment'));
    }
    
    public function actionUpdate($id)
    {
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        $model   = SupportTicketDepartment::model()->findByPk((int)$id);
        
        $userToDepartment = new UserToSupportTicketDepartment();
        
        if (empty($model)) {
            throw new CHttpException(404, Yii::t('app', 'The requested page does not exist.'));
        }
        
        if ($request->isPostRequest && ($attributes = (array)$request->getPost($model->modelName, array()))) {
            $model->attributes = $attributes;
            if (!$model->save()) {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            } else {
                UserToSupportTicketDepartment::model()->deleteAllByAttributes(array('department_id' => $model->department_id));
                if ($assignedUsers = (array)$request->getPost($userToDepartment->modelName, array())) {
                    $assignedUsers = array_map('intval', $assignedUsers);
                    foreach ($assignedUsers as $userId) {
                        $assign = new UserToSupportTicketDepartment();
                        $assign->user_id       = $userId;
                        $assign->department_id = $model->department_id;
                        $assign->save();
                    }
                }
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
            }
            
            Yii::app()->hooks->doAction('controller_action_save_data', $collection = new CAttributeCollection(array(
                'controller'=> $this,
                'success'   => $notify->hasSuccess,
                'model'     => $model,
            )));
            
            if ($collection->success) {
                $this->redirect(array($this->id . '/index'));
            }
        }
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets departments'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets departments'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl('support_tickets_ext/index'),
                Yii::t('ext_support_tickets', 'Departments')  => $this->createUrl($this->id . '/index'),
                Yii::t('app', 'Update'),
            )
        ));

        $this->render('form', compact('model', 'userToDepartment'));
    }
    
    public function actionDelete($id)
    {
        $model = SupportTicketDepartment::model()->findByPk((int)$id);
        
        if (empty($model)) {
            throw new CHttpException(404, Yii::t('app', 'The requested page does not exist.'));
        }
        
        $model->delete();
        
        $request = Yii::app()->request;
        $notify  = Yii::app()->notify;
        
        if (!$request->getQuery('ajax')) {
            $notify->addSuccess(Yii::t('app', 'The item has been successfully deleted!'));
            $this->redirect($request->getPost('returnUrl', array($this->id . '/index')));
        }
    }
}