<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */

/**
 * This hook gives a chance to prepend content or to replace the default view content with a custom content.
 * Please note that from inside the action callback you can access all the controller view
 * variables via {@CAttributeCollection $collection->controller->data}
 * In case the content is replaced, make sure to set {@CAttributeCollection $collection->renderContent} to false 
 * in order to stop rendering the default content.
 * @since 1.3.3.1
 */
$hooks->doAction('before_view_file_content', $viewCollection = new CAttributeCollection(array(
    'controller'    => $this,
    'renderContent' => true,
)));

// and render if allowed
if ($viewCollection->renderContent) { ?>
    <div class="box box-primary">
        <div class="box-header">
            <div class="pull-left">
                <h3 class="box-title">
                    <span class="glyphicon glyphicon-book"></span> <?php echo $pageHeading;?>
                </h3>
            </div>
            <div class="pull-right">
                <?php echo CHtml::link(Yii::t('app', 'Create new'), array($this->id . '/create'), array('class' => 'btn btn-primary btn-xs', 'title' => Yii::t('app', 'Create new')));?>
                <?php echo CHtml::link(Yii::t('app', 'Refresh'), array($this->id . '/index'), array('class' => 'btn btn-primary btn-xs', 'title' => Yii::t('app', 'Refresh')));?>
            </div>
            <div class="clearfix"><!-- --></div>
        </div>
        <div class="box-body">
            <div class="table-responsive">
            <?php 
            /**
             * This hook gives a chance to prepend content or to replace the default grid view content with a custom content.
             * Please note that from inside the action callback you can access all the controller view
             * variables via {@CAttributeCollection $collection->controller->data}
             * In case the content is replaced, make sure to set {@CAttributeCollection $collection->renderGrid} to false 
             * in order to stop rendering the default content.
             * @since 1.3.3.1
             */
            $hooks->doAction('before_grid_view', $collection = new CAttributeCollection(array(
                'controller'   => $this,
                'renderGrid'   => true,
            )));
            
            // and render if allowed
            if ($collection->renderGrid) {
                $this->widget('zii.widgets.grid.CGridView', $hooks->applyFilters('grid_view_properties', array(
                    'ajaxUrl'         => $this->createUrl($this->route),
                    'id'              => $ticket->modelName.'-grid',
                    'dataProvider'    => $ticket->search(),
                    'filter'          => $ticket,
                    'filterPosition'  => 'body',
                    'filterCssClass'  => 'grid-filter-cell',
                    'itemsCssClass'   => 'table table-bordered table-hover table-striped',
                    'selectableRows'  => 0,
                    'enableSorting'   => false,
                    'cssFile'         => false,
                    'pagerCssClass'   => 'pagination pull-right',
                    'pager'           => array(
                        'class'       => 'CLinkPager',
                        'cssFile'     => false,
                        'header'      => false,
                        'htmlOptions' => array('class' => 'pagination')
                    ),
                    'columns' => $hooks->applyFilters('grid_view_columns', array(
                        array(
                            'name'  => 'subject',
                            'value' => 'CHtml::link($data->subject, array("support_tickets_ext/view", "id" => $data->ticket_id))',
                            'type'  => 'raw',
                        ),
                        array(
                            'name'  => 'user_id',
                            'value' => '!empty($data->user_id) ? CHtml::link($data->user->fullName, array("users/update", "id" => $data->user_id)) : null',
                            'type'  => 'raw',
                        ),
                        array(
                            'name'  => 'customer_id',
                            'value' => '!empty($data->customer_id) ? CHtml::link($data->customer->fullName, array("customers/update", "id" => $data->customer_id)) : null',
                            'type'  => 'raw',
                        ),
                        array(
                            'name'  => 'department_id',
                            'value' => '!empty($data->department_id) ? CHtml::link($data->department->name, array("support_tickets_ext_departments/update", "id" => $data->department_id)) : null',
                            'filter'=> CMap::mergeArray(array('' => ''), $ticket->getDepartmentsList()),
                            'type'  => 'raw',
                        ),
                        array(
                            'name'  => 'priority_id',
                            'value' => '!empty($data->priority_id) ? CHtml::link($data->priority->name, array("support_tickets_ext_departments/update", "id" => $data->priority_id)) : null',
                            'filter'=> CMap::mergeArray(array('' => ''), $ticket->getPrioritiesList()),
                            'type'  => 'raw',
                        ),
                        array(
                            'name'  => 'status',
                            'value' => '$data->statusName',
                            'filter'=> $ticket->getStatusesList(),
                        ),
                        array(
                            'name'   => 'date_added',
                            'value'  => '$data->dateAdded',
                            'filter' => false,
                        ),
                        array(
                            'name'   => 'last_updated',
                            'value'  => '$data->lastUpdated',
                            'filter' => false,
                        ),
                        array(
                            'class'  => 'CButtonColumn',
                            'header' => Yii::t('app', 'Options'),
                            'footer' => $ticket->paginationOptions->getGridFooterPagination(),
                            'buttons'=> array(
                                'view' => array(
                                    'label'    => ' &nbsp; <span class="glyphicon glyphicon-eye-open"></span> &nbsp;', 
                                    'url'      => 'Yii::app()->createUrl("support_tickets_ext/view", array("id" => $data->ticket_id))',
                                    'imageUrl' => null,
                                    'options'  => array('title' => Yii::t('app', 'View'), 'class' => ''),
                                ),
                                'update' => array(
                                    'label'    => ' &nbsp; <span class="glyphicon glyphicon-pencil"></span> &nbsp;', 
                                    'url'      => 'Yii::app()->createUrl("support_tickets_ext/update", array("id" => $data->ticket_id))',
                                    'imageUrl' => null,
                                    'options'  => array('title' => Yii::t('app', 'Update'), 'class' => ''),
                                ),
                                'delete' => array(
                                    'label'    => ' &nbsp; <span class="glyphicon glyphicon-remove-circle"></span> &nbsp; ', 
                                    'url'      => 'Yii::app()->createUrl("support_tickets_ext/delete", array("id" => $data->ticket_id))',
                                    'imageUrl' => null,
                                    'options'  => array('title' => Yii::t('app', 'Delete'), 'class' => 'delete'),
                                ),    
                            ),
                            'htmlOptions' => array(
                                'style' => 'width:110px;',
                            ),
                            'template' => '{view} {update} {delete}'
                        ),
                    ), $this),
                ), $this));  
            }
            /**
             * This hook gives a chance to append content after the grid view content.
             * Please note that from inside the action callback you can access all the controller view
             * variables via {@CAttributeCollection $collection->controller->data}
             * @since 1.3.3.1
             */
            $hooks->doAction('after_grid_view', new CAttributeCollection(array(
                'controller'   => $this,
                'renderedGrid' => $collection->renderGrid,
            )));
            ?>
            <div class="clearfix"><!-- --></div>
            </div>    
        </div>
    </div>
<?php 
}
/**
 * This hook gives a chance to append content after the view file default content.
 * Please note that from inside the action callback you can access all the controller view
 * variables via {@CAttributeCollection $collection->controller->data}
 * @since 1.3.3.1
 */
$hooks->doAction('after_view_file_content', new CAttributeCollection(array(
    'controller'        => $this,
    'renderedContent'   => $viewCollection->renderContent,
)));