<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */

/**
 * This hook gives a chance to prepend content or to replace the default view content with a custom content.
 * Please note that from inside the action callback you can access all the controller view
 * variables via {@CAttributeCollection $collection->controller->data}
 * In case the content is replaced, make sure to set {@CAttributeCollection $collection->renderContent} to false 
 * in order to stop rendering the default content.
 * @since 1.3.3.1
 */
$hooks->doAction('before_view_file_content', $viewCollection = new CAttributeCollection(array(
    'controller'    => $this,
    'renderContent' => true,
)));

// and render if allowed
if ($viewCollection->renderContent) {
    ?>
    <div class="box box-primary">
        <div class="box-header">
            <div class="pull-left">
                <h3 class="box-title ticket-box-title">
                    <div class="pull-left ticket-header-avatar">
                        <?php echo CHtml::link(CHtml::image($ticket->customer->getAvatarUrl(50, 50), $ticket->customer->fullName, array('class' => 'img-thumbnail')), array('customers/update', 'id' => $ticket->customer_id), array('title' => $ticket->customer->fullName)); ?>     
                    </div>
                    <div class="pull-left ticket-header-info">
                        <?php echo Yii::t('ext_support_tickets', 'Ticket #{num}', array(
                            '{num}'  => $ticket->ticket_id,
                        ));?>
                        <br />
                        <?php echo Yii::t('ext_support_tickets', 'Subject: {subject}', array(
                            '{subject}'  => $ticket->subject,
                        ));?>
                    </div>
                </h3>
            </div>
            <div class="pull-right">
                <?php echo CHtml::link(Yii::t('app', 'Update'), array($this->id . '/update', 'id' => $ticket->ticket_id), array('class' => 'btn btn-primary btn-xs', 'title' => Yii::t('app', 'Update')));?>
                <?php echo CHtml::link(Yii::t('app', 'Back'), array($this->id . '/index'), array('class' => 'btn btn-primary btn-xs', 'title' => Yii::t('app', 'Back')));?>
            </div>
            <div class="clearfix"><!-- --></div>
        </div>
        <div class="box-body">
            <div class="clearfix"><!-- --></div>
            <?php echo $ticket->content;?>
            <div class="clearfix"><!-- --></div>
        </div>
        <div class="box-footer">
            <div class="table-responsive">
                <table class="table table-striped table-bordered table-hover table-condensed">
                    <thead>
                        <th><?php echo Yii::t('ext_support_tickets', 'Assigned to');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Customer');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Department');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Priority');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Ip address');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Rating');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Status');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Date added');?></th>
                        <th><?php echo Yii::t('ext_support_tickets', 'Last updated');?></th>
                    </thead>
                    <tbody>
                        <tr>
                            <td><?php echo empty($ticket->user_id) ? '-' : CHtml::link($ticket->user->fullName, array('users/update', 'id' => $ticket->user_id));?></td>
                            <td><?php echo empty($ticket->customer_id) ? '-' : CHtml::link($ticket->customer->fullName, array('customers/update', 'id' => $ticket->customer_id));?></td>
                            <td><?php echo empty($ticket->department_id) ? '-' : CHtml::link($ticket->department->name, array('support_tickets_ext_departments/update', 'id' => $ticket->department_id));?></td>
                            <td><?php echo empty($ticket->priority_id) ? '-' : CHtml::link($ticket->priority->name, array('support_tickets_ext_priorities/update', 'id' => $ticket->priority_id));?></td>
                            <td><?php echo $ticket->ip_address;?></td>
                            <td><?php echo $ticket->rating > 0 ? $ticket->rating : '-';?></td>
                            <td><?php echo $ticket->statusName;?></td>
                            <td><?php echo $ticket->dateAdded;?></td>
                            <td><?php echo $ticket->lastUpdated;?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
            <div class="clearfix"><!-- --></div>
        </div>
    </div>
    <hr />
    <?php
    /**
     * This hook gives a chance to prepend content before the active form or to replace the default active form entirely.
     * Please note that from inside the action callback you can access all the controller view variables 
     * via {@CAttributeCollection $collection->controller->data}
     * In case the form is replaced, make sure to set {@CAttributeCollection $collection->renderForm} to false 
     * in order to stop rendering the default content.
     * @since 1.3.3.1
     */
    $hooks->doAction('before_active_form', $collection = new CAttributeCollection(array(
        'controller'    => $this,
        'renderForm'    => true,
    )));
    
    // and render if allowed
    if ($collection->renderForm) {
        $form = $this->beginWidget('CActiveForm'); 
        ?>
        <div class="box box-primary">
            <div class="box-header">
                <div class="pull-left">
                    <h3 class="box-title"><?php echo Yii::t('ext_support_tickets', 'Reply to this ticket');?></h3>
                </div>
                <div class="clearfix"><!-- --></div>
            </div>
            <div class="box-body">
                <?php 
                /**
                 * This hook gives a chance to prepend content before the active form fields.
                 * Please note that from inside the action callback you can access all the controller view variables 
                 * via {@CAttributeCollection $collection->controller->data}
                 * @since 1.3.3.1
                 */
                $hooks->doAction('before_active_form_fields', new CAttributeCollection(array(
                    'controller'    => $this,
                    'form'          => $form    
                )));
                ?>
                <div class="clearfix"><!-- --></div>
                <div class="form-group">
                    <?php /* echo $form->labelEx($reply, 'content'); */?>
                    <?php echo $form->textArea($reply, 'content', $reply->getHtmlOptions('content')); ?>
                    <?php echo $form->error($reply, 'content');?>
                </div>
                <div class="clearfix"><!-- --></div>
                <?php 
                /**
                 * This hook gives a chance to append content after the active form fields.
                 * Please note that from inside the action callback you can access all the controller view variables 
                 * via {@CAttributeCollection $collection->controller->data}
                 * @since 1.3.3.1
                 */
                $hooks->doAction('after_active_form_fields', new CAttributeCollection(array(
                    'controller'    => $this,
                    'form'          => $form    
                )));
                ?>
                <div class="clearfix"><!-- --></div>
            </div>
            <div class="box-footer">
                <div class="pull-right">
                    <?php echo $form->dropDownList($reply, 'after_save_action', $reply->getAfterSaveActions(), $reply->getHtmlOptions('after_save_action'));?>
                </div>
                <div class="pull-right">&nbsp;</div>
                <div class="pull-right">
                    <button type="submit" class="btn btn-primary btn-submit" data-loading-text="<?php echo Yii::t('app', 'Please wait, processing...');?>"><?php echo Yii::t('ext_support_tickets', 'Send reply');?></button>
                </div>
                <div class="clearfix"><!-- --></div>
            </div>
        </div>
        <?php 
        $this->endWidget(); 
    }
    /**
     * This hook gives a chance to append content after the active form.
     * Please note that from inside the action callback you can access all the controller view variables 
     * via {@CAttributeCollection $collection->controller->data}
     * @since 1.3.3.1
     */
    $hooks->doAction('after_active_form', new CAttributeCollection(array(
        'controller'      => $this,
        'renderedForm'    => $collection->renderForm,
    )));
    ?>
    <hr />
    <?php if (!empty($ticket->replies)) { ?>
    <h4><?php 
    $count = count($ticket->replies);
    if ($count > 1) {
        echo Yii::t('ext_support_tickets', 'Showing all {n} replies:', '<span class="replies-counter">'. count($ticket->replies) .'</span>');    
    } else {
        echo Yii::t('ext_support_tickets', 'Showing {n} reply:', '<span class="replies-counter">'. count($ticket->replies) .'</span>');
    }
    ?></h4>
    <?php foreach ($ticket->replies as $reply) { ?>
    <div class="box box-primary" id="reply-<?php echo $reply->reply_id;?>">
        <div class="box-header">
            <div class="pull-left">
                <h3 class="box-title reply-box-title">
                    <div class="pull-left reply-header-avatar">
                        <?php if (!empty($reply->user_id)) {
                            echo CHtml::link(CHtml::image($reply->user->getAvatarUrl(50, 50), $reply->user->fullName, array('class' => 'img-thumbnail')), array('users/update', 'id' => $reply->user_id), array('title' => $reply->user->fullName));
                        } else { 
                            echo CHtml::link(CHtml::image($reply->customer->getAvatarUrl(50, 50), $reply->customer->fullName, array('class' => 'img-thumbnail')), array('customers/update', 'id' => $reply->customer_id), array('title' => $reply->customer->fullName));
                        } ?>    
                    </div>
                    <div class="pull-left reply-header-info">
                        <a name="reply-<?php echo $reply->reply_id;?>"></a>
                        <?php echo CHtml::link(Yii::t('ext_support_tickets', 'Reply #{num}', array('{num}'=>$reply->reply_id)), Yii::app()->apps->getAppUrl('backend', 'support-tickets/view/id/' . $reply->ticket_id . '#reply-' . $reply->reply_id, true));?>
                        <br />
                        <?php echo Yii::t('ext_support_tickets', 'Posted by {name}', array(
                            '{name}' => !empty($reply->user_id) ? sprintf('%s(%s)', CHtml::link($reply->user->fullName, array('users/update', 'id' => $reply->user_id)), Yii::t('ext_support_tickets', 'Support team')) : sprintf('%s(%s)', CHtml::link($reply->customer->fullName, array('customers/update', 'id' => $reply->customer_id)), Yii::t('ext_support_tickets', 'Customer')),
                        ));?>
                        <br />
                        <?php echo Yii::t('ext_support_tickets', 'From {ip} at {date}', array(
                            '{ip}'   => CHtml::link($reply->ip_address, "http://who.is/whois-ip/ip-address/".$reply->ip_address, array('target' => '_blank')),
                            '{date}' => $reply->dateAdded,
                        ));?>
                    </div>
                </h3>
            </div>
            <div class="pull-right">
                <?php echo CHtml::link(Yii::t('ext_support_tickets', 'Delete this reply'), array($this->id . '/delete_reply', 'id' => $reply->reply_id), array('class' => 'btn btn-danger btn-xs btn-delete-reply', 'title' => Yii::t('ext_support_tickets', 'Delete this reply'), 'data-confirm' => Yii::t('app', 'Are you sure you want to remove this item?')));?>
            </div>
            <div class="clearfix"><!-- --></div>
        </div>
        <div class="box-body">
            <div class="clearfix"><!-- --></div>
            <?php echo $reply->content;?>
            <div class="clearfix"><!-- --></div>
        </div>
        <div class="box-footer">
            <div class="pull-right">
                <?php echo $reply->rating > 0 ? Yii::t('ext_support_tickets', 'Reply rated {rate} out of {max}', array('{rate}' => $reply->rating, '{max}' => max(array_keys($reply->getRatingOptions())))) : '';?>
            </div>
            <div class="clearfix"><!-- --></div>
        </div>
    </div>
    <?php } ?>
    <?php } ?>
    <?php
}
/**
 * This hook gives a chance to append content after the view file default content.
 * Please note that from inside the action callback you can access all the controller view
 * variables via {@CAttributeCollection $collection->controller->data}
 * @since 1.3.3.1
 */
$hooks->doAction('after_view_file_content', new CAttributeCollection(array(
    'controller'        => $this,
    'renderedContent'   => $viewCollection->renderContent,
)));