SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='';

-- -----------------------------------------------------
-- Table `support_ticket_priority`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `support_ticket_priority` (
  `priority_id` INT NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(50) NOT NULL,
  `date_added` DATETIME NOT NULL,
  `last_updated` DATETIME NOT NULL,
  PRIMARY KEY (`priority_id`))
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `support_ticket_department`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `support_ticket_department` (
  `department_id` INT NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(50) NOT NULL,
  `date_added` DATETIME NOT NULL,
  `last_updated` DATETIME NOT NULL,
  PRIMARY KEY (`department_id`))
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `support_ticket`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `support_ticket` (
  `ticket_id` INT NOT NULL AUTO_INCREMENT,
  `user_id` INT NULL,
  `customer_id` INT NOT NULL,
  `department_id` INT NULL,
  `priority_id` INT NULL,
  `subject` VARCHAR(255) NOT NULL,
  `content` TEXT NOT NULL,
  `replies_count` INT(11) NOT NULL DEFAULT 0,
  `rating` DECIMAL(3,2) NOT NULL DEFAULT 0.00,
  `ip_address` VARCHAR(15) NOT NULL,
  `status` CHAR(30) NOT NULL DEFAULT 'open',
  `date_added` DATETIME NOT NULL,
  `last_updated` DATETIME NOT NULL,
  PRIMARY KEY (`ticket_id`),
  INDEX `fk_support_ticket_support_ticket_priority1_idx` (`priority_id` ASC),
  INDEX `fk_support_ticket_support_ticket_department1_idx` (`department_id` ASC),
  INDEX `fk_support_ticket_user1_idx` (`user_id` ASC),
  INDEX `fk_support_ticket_customer1_idx` (`customer_id` ASC),
  CONSTRAINT `fk_support_ticket_support_ticket_priority1`
    FOREIGN KEY (`priority_id`)
    REFERENCES `support_ticket_priority` (`priority_id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_support_ticket_support_ticket_department1`
    FOREIGN KEY (`department_id`)
    REFERENCES `support_ticket_department` (`department_id`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_support_ticket_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `user` (`user_id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_support_ticket_customer1`
    FOREIGN KEY (`customer_id`)
    REFERENCES `customer` (`customer_id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `support_ticket_reply`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `support_ticket_reply` (
  `reply_id` INT NOT NULL AUTO_INCREMENT,
  `ticket_id` INT NOT NULL,
  `user_id` INT NULL,
  `customer_id` INT NULL,
  `content` TEXT NOT NULL,
  `rating` TINYINT(1) NOT NULL DEFAULT 0,
  `ip_address` VARCHAR(15) NOT NULL,
  `date_added` DATETIME NOT NULL,
  `last_updated` DATETIME NOT NULL,
  PRIMARY KEY (`reply_id`),
  INDEX `fk_support_ticket_reply_support_ticket_idx` (`ticket_id` ASC),
  INDEX `fk_support_ticket_reply_user1_idx` (`user_id` ASC),
  INDEX `fk_support_ticket_reply_customer1_idx` (`customer_id` ASC),
  CONSTRAINT `fk_support_ticket_reply_support_ticket`
    FOREIGN KEY (`ticket_id`)
    REFERENCES `support_ticket` (`ticket_id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_support_ticket_reply_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `user` (`user_id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_support_ticket_reply_customer1`
    FOREIGN KEY (`customer_id`)
    REFERENCES `customer` (`customer_id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `user_to_support_ticket_department`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `user_to_support_ticket_department` (
  `user_id` INT NOT NULL,
  `department_id` INT NOT NULL,
  PRIMARY KEY (`user_id`, `department_id`),
  INDEX `fk_user_to_support_ticket_department_support_ticket_departm_idx` (`department_id` ASC),
  INDEX `fk_user_to_support_ticket_department_user1_idx` (`user_id` ASC),
  CONSTRAINT `fk_user_to_support_ticket_department_user1`
    FOREIGN KEY (`user_id`)
    REFERENCES `user` (`user_id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_user_to_support_ticket_department_support_ticket_department1`
    FOREIGN KEY (`department_id`)
    REFERENCES `support_ticket_department` (`department_id`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB DEFAULT CHARSET=utf8;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
