<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * SupportTicketsExtModel
 * 
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */
 
/**
 * This is the model class for table "support_ticket_priority".
 *
 * The followings are the available columns in table 'support_ticket_priority':
 * @property integer $priority_id
 * @property string $name
 * @property string $date_added
 * @property string $last_updated
 *
 * The followings are the available model relations:
 * @property SupportTicket[] $tickets
 */
class SupportTicketPriority extends ActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{support_ticket_priority}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		$rules = array(
			array('name', 'required'),
			array('name', 'length', 'max'=>50),
            
			// The following rule is used by search().
			array('name', 'safe', 'on'=>'search'),
		);
        
        return CMap::mergeArray($rules, parent::rules());
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		$relations = array(
			'tickets' => array(self::HAS_MANY, 'SupportTicket', 'priority_id'),
		);
        
        return CMap::mergeArray($relations, parent::relations());
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		$labels = array(
			'priority_id' => Yii::t('ext_support_tickets', 'Priority'),
			'name'        => Yii::t('ext_support_tickets', 'Name'),
		);
        
        return CMap::mergeArray($labels, parent::attributeLabels());
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		$criteria=new CDbCriteria;
        $criteria->compare('name',$this->name,true);

		return new CActiveDataProvider(get_class($this), array(
            'criteria'     => $criteria,
            'pagination'   => array(
                'pageSize' => $this->paginationOptions->getPageSize(),
                'pageVar'  => 'page',
            ),
            'sort'  => array(
                'defaultOrder' => array(
                    't.priority_id' => CSort::SORT_DESC,
                ),
            ),
        ));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return SupportTicketPriority the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
