<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * SupportTicketsExtModel
 * 
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */
 
/**
 * This is the model class for table "support_ticket_reply".
 *
 * The followings are the available columns in table 'support_ticket_reply':
 * @property integer $reply_id
 * @property integer $ticket_id
 * @property integer $user_id
 * @property integer $customer_id
 * @property string $content
 * @property integer $rating
 * @property string $ip_address
 * @property string $date_added
 * @property string $last_updated
 *
 * The followings are the available model relations:
 * @property SupportTicket $ticket
 * @property User $user
 * @property Customer $customer
 */
class SupportTicketReply extends ActiveRecord
{
    const AFTER_SAVE_ACTION_CLOSE_SEND      = 'close ticket and send reply email';
    
    const AFTER_SAVE_ACTION_CLOSE_DONT_SEND = 'close ticket and do not send reply email';
    
    public $after_save_action = '';
    
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{support_ticket_reply}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		$rules = array(
			array('content', 'required'),
            array('rating', 'in', 'range' => array_keys($this->getRatingOptions())),
            array('after_save_action', 'in', 'range' => array_keys($this->getAfterSaveActions())),
		);
        
        return CMap::mergeArray($rules, parent::rules());
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		$relations = array(
			'ticket'   => array(self::BELONGS_TO, 'SupportTicket', 'ticket_id'),
			'user'     => array(self::BELONGS_TO, 'User', 'user_id'),
			'customer' => array(self::BELONGS_TO, 'Customer', 'customer_id'),
		);
        
        return CMap::mergeArray($relations, parent::relations());
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		$labels = array(
			'reply_id'    => Yii::t('ext_support_tickets', 'Reply'),
			'ticket_id'   => Yii::t('ext_support_tickets', 'Ticket'),
			'user_id'     => Yii::t('ext_support_tickets', 'User'),
			'customer_id' => Yii::t('ext_support_tickets', 'Customer'),
			'content'     => Yii::t('ext_support_tickets', 'Content'),
			'rating'      => Yii::t('ext_support_tickets', 'Rating'),
            'ip_address'  => Yii::t('ext_support_tickets', 'Ip address'),
		);
        
        return CMap::mergeArray($labels, parent::attributeLabels());
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return SupportTicketReply the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
    
    public function afterDelete()
    {
        if (!empty($this->ticket)) {
            $this->ticket->save(false);
        }
        parent::afterDelete();    
    }
    
    public function afterSave()
    {
        if (!empty($this->ticket)) {
            $this->ticket->save(false);
        }
        parent::afterSave();    
    }
    
    public function getRatingOptions()
    {
        $options = array(0 => '');
        for ($i = 5; $i > 0; --$i) {
            $options[$i] = $i;
        } 
        return $options;
    }
    
    public function getCanBeRated()
    {
        $model = Yii::app()->extensionsManager->getExtensionInstance('support-tickets')->getExtModel();
        return !$this->isNewRecord && 
            !empty($this->user_id) && 
            $model->rating_enabled == SupportTicketsExtModel::TEXT_YES && 
            strtotime($this->date_added) + (3600 * (int)$model->rating_timeframe) > time() &&
            $this->ticket->status != SupportTicket::STATUS_CLOSED;
    }
    
    public function getAfterSaveActions()
    {
        return array(
            ''  => Yii::t('ext_support_tickets', 'And'),
            self::AFTER_SAVE_ACTION_CLOSE_DONT_SEND => Yii::t('ext_support_tickets', ucfirst(self::AFTER_SAVE_ACTION_CLOSE_DONT_SEND)),
            self::AFTER_SAVE_ACTION_CLOSE_SEND      => Yii::t('ext_support_tickets', ucfirst(self::AFTER_SAVE_ACTION_CLOSE_SEND)),
        );
    }   
}
