<?php defined('MW_PATH') || exit('No direct script access allowed');

/**
 * SupportTicketsExtModel
 * 
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */
 
class SupportTicketsExtModel extends FormModel
{
    const TEXT_YES = 'yes';
    
    const TEXT_NO = 'no';
    
    protected $_extensionInstance;
    
    public $rating_enabled   = 'yes';
    
    public $rating_timeframe = 24;
    
    public $inactive_close_days = 3;
    
    public $groups = array();
    
    public function rules()
    {
        $rules = array(
            array('rating_enabled, rating_timeframe, inactive_close_days', 'required'),
            array('rating_enabled', 'in', 'range' => array_keys($this->getYesNoOptions())),
            array('rating_timeframe, inactive_close_days', 'numerical', 'integerOnly' => true, 'min' => 1, 'max' => 365),
            array('groups', '_handleGroups'),
        );
        
        return CMap::mergeArray($rules, parent::rules());    
    }
    
    public function attributeLabels()
    {
        $labels = array(
            'rating_enabled'      => Yii::t('ext_support_tickets', 'Rating enabled'),
            'rating_timeframe'    => Yii::t('ext_support_tickets', 'Rating timeframe'),
            'inactive_close_days' => Yii::t('ext_support_tickets', 'Inactive tickets close days'),
            'groups'              => Yii::t('ext_support_tickets', 'Provide support only for these customer groups'),
        );
        return CMap::mergeArray($labels, parent::attributeLabels());    
    }
    
    public function attributePlaceholders()
    {
        $placeholders = array(
            'rating_timeframe'   => 24,
            'inactive_keep_open' => 3,
        );
        return CMap::mergeArray($placeholders, parent::attributePlaceholders());
    }
    
    public function attributeHelpTexts()
    {
        $texts = array(
            'rating_enabled'      => Yii::t('ext_support_tickets', 'Whether rating is enabled and customer are able to rate your replies'),
            'rating_timeframe'    => Yii::t('ext_support_tickets', 'After how many hours should we deny the customer the ability to rate a staff reply'),
            'inactive_close_days' => Yii::t('ext_support_tickets', 'After how many days inactive tickets should be closed automatically'),
        );
        return CMap::mergeArray($texts, parent::attributeHelpTexts());
    }
    
    public function save()
    {
        $extension  = $this->getExtensionInstance();
        $attributes = array_keys(get_object_vars($this));
        foreach ($attributes as $name) {
            $reflection = new ReflectionProperty($this, $name);
            if (!$reflection->isPublic()) {
                continue;
            }
            $extension->setOption($name, $this->$name);
        }
        return $this;
    }
    
    public function populate() 
    {
        $extension  = $this->getExtensionInstance();
        $attributes = array_keys(get_object_vars($this));
        foreach ($attributes as $name) {
            $reflection = new ReflectionProperty($this, $name);
            if (!$reflection->isPublic()) {
                continue;
            }
            $this->$name = $extension->getOption($name, $this->$name);
        }
        return $this;
    }
    
    public function setExtensionInstance($instance)
    {
        $this->_extensionInstance = $instance;
        return $this;
    }
    
    public function getExtensionInstance()
    {
        if ($this->_extensionInstance !== null) {
            return $this->_extensionInstance;
        }
        return $this->_extensionInstance = Yii::app()->extensionsManager->getExtensionInstance('support-tickets');
    }
    
    public function getYesNoOptions()
    {
        return array(
            self::TEXT_YES => ucfirst(Yii::t('app', self::TEXT_YES)),
            self::TEXT_NO  => ucfirst(Yii::t('app', self::TEXT_NO)),
        );
    }
    
    public function getCustomerGroupsOptions()
    {
        static $options;
        if ($options !== null) {
            return $options;
        }
        $options = array();
        $groups  = CustomerGroup::model()->findAll();
        foreach ($groups as $group) {
            $options[$group->group_id] = $group->name;
        }
        return $options;
    }
    
    public function _handleGroups($attribute, $params)
    {
        if (empty($this->$attribute) || !is_array($this->$attribute)) {
            $this->$attribute = array();
        }
        $this->$attribute = array_map('intval', $this->$attribute);
        $this->$attribute = array_filter($this->$attribute);
    }
}
