<?php defined('MW_PATH') || exit('No direct script access allowed');

/** 
 * Controller file.
 * 
 * @package MailWizz EMA
 * @subpackage Support tickets
 * @author Serban George Cristian <cristian.serban@mailwizz.com> 
 * @link http://www.mailwizz.com/
 * @copyright 2013-2014 MailWizz EMA (http://www.mailwizz.com)
 * @license http://www.mailwizz.com/license/
 */
 
class Support_tickets_extController extends Controller
{
    // the extension instance
    public $extension;
    
    public function init()
    {
        $this->onBeforeAction = array($this, '_handleAssetsRegistration');
        parent::init();
    }

    // move the view path
    public function getViewPath()
    {
        return Yii::getPathOfAlias('ext-support-tickets.customer.views');
    }
    
    public function actionIndex()
    {
        $request = Yii::app()->request;
        $ticket  = new SupportTicket('search');
        
        $ticket->unsetAttributes();
        $ticket->attributes  = (array)$request->getQuery($ticket->modelName, array());
        $ticket->customer_id = Yii::app()->customer->getId();
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                Yii::t('ext_support_tickets', 'View all'),
            )
        ));

        $this->render('list', compact('ticket'));
    }
    
    public function actionCreate()
    {
        $request  = Yii::app()->request;
        $notify   = Yii::app()->notify;
        $options  = Yii::app()->options;
        $ticket   = new SupportTicket();
        $customer = Yii::app()->customer->getmodel();

        if ($request->isPostRequest && ($attributes = (array)$request->getPost($ticket->modelName, array()))) {
            $ticket->attributes  = $attributes;
            $ticket->content     = Yii::app()->ioFilter->purify(Yii::app()->params['POST'][$ticket->modelName]['content']);
            $ticket->customer_id = $customer->customer_id;
            $ticket->ip_address  = $request->getUserHostAddress();
            $ticket->status      = SupportTicket::STATUS_WAITING_STAFF_REPLY;
            
            if (!$ticket->save()) {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            } else {
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
                
                if (!empty($ticket->department_id) && !empty($ticket->department) && !empty($ticket->department->users)) {
                    $users = $ticket->department->users;
                } else {
                    $users = User::model()->findAllByAttributes(array('status' => User::STATUS_ACTIVE));
                }
                
                foreach ($users as $user) {
                    // send email to user
                    $emailTemplate = $options->get('system.email_templates.common');
                    $emailBody     = $this->renderPartial('emails/_ticket-to-user', compact('ticket', 'user', 'customer'), true);
                    $emailTemplate = str_replace('[CONTENT]', $emailBody, $emailTemplate);
                    
                    $email = new TransactionalEmail();
                    $email->to_name   = $user->getFullName();
                    $email->to_email  = $user->email;
                    $email->from_name = Yii::t('ext_support_tickets', '{site} support', array('{site}' => $options->get('system.common.site_name', 'Marketing website')));
                    $email->subject   = Yii::t('ext_support_tickets', '[{site} support] {subject}', array(
                        '{site}'    => $options->get('system.common.site_name', 'Marketing website'),
                        '{subject}' => $ticket->subject,
                    ));
                    $email->body      = $emailTemplate;
                    $email->save();    
                }
            }
            
            Yii::app()->hooks->doAction('controller_action_save_data', $collection = new CAttributeCollection(array(
                'controller'=> $this,
                'success'   => $notify->hasSuccess,
                'ticket'    => $ticket,
            )));
            
            if ($collection->success) {
                $this->redirect(array($this->id . '/index'));
            }
        }
        
        $ticket->fieldDecorator->onHtmlOptionsSetup = array($this, '_setupEditorOptions');
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'Support tickets'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'Support tickets'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                Yii::t('app', 'Create new'),
            )
        ));

        $this->render('form', compact('ticket'));
    }
    
    public function actionView($id)
    {
        $request  = Yii::app()->request;
        $notify   = Yii::app()->notify;
        $options  = Yii::app()->options;
        $customer = Yii::app()->customer->getmodel();
        $ticket   = SupportTicket::model()->findByAttributes(array('ticket_id' => $id, 'customer_id' => $customer->customer_id));
        $reply    = new SupportTicketReply();
        
        if (empty($ticket)) {
            throw new CHttpException(404, Yii::t('app', 'The requested page does not exist.'));
        }
        
        if ($request->isPostRequest && ($attributes = (array)$request->getPost($reply->modelName, array()))) {
            $reply->attributes  = $attributes;
            $reply->content     = Yii::app()->ioFilter->purify(Yii::app()->params['POST'][$reply->modelName]['content']);
            $reply->ticket_id   = $ticket->ticket_id;
            $reply->customer_id = $customer->customer_id;
            $reply->ip_address  = $request->getUserHostAddress();
            
            if (!$reply->save()) {
                $notify->addError(Yii::t('app', 'Your form has a few errors, please fix them and try again!'));
            } else {
                $notify->addSuccess(Yii::t('app', 'Your form has been successfully saved!'));
                $ticket->status = SupportTicket::STATUS_WAITING_STAFF_REPLY;

                if ($reply->after_save_action == SupportTicketReply::AFTER_SAVE_ACTION_CLOSE_SEND || 
                    $reply->after_save_action == SupportTicketReply::AFTER_SAVE_ACTION_CLOSE_DONT_SEND) {
                    $ticket->status = SupportTicket::STATUS_CLOSED;
                }
                
                $ticket->save(false);
                
                $sendEmail = true;
                if ($reply->after_save_action == SupportTicketReply::AFTER_SAVE_ACTION_CLOSE_DONT_SEND) {
                    $sendEmail = false;
                }
                
                if ($sendEmail) {
                    
                    // find the user(s)
                    if (empty($ticket->user_id)) {
                        if (!empty($ticket->department_id) && !empty($ticket->department) && !empty($ticket->department->users)) {
                            $users = $ticket->department->users;
                        } else {
                            $users = User::model()->findAllByAttributes(array('status' => User::STATUS_ACTIVE));
                        }    
                    } else {
                        $users = array($ticket->user);
                    }

                    foreach ($users as $user) {
                        // send email to user
                        $emailTemplate = $options->get('system.email_templates.common');
                        $emailBody     = $this->renderPartial('emails/_reply-to-user', compact('ticket', 'reply', 'user', 'customer'), true);
                        $emailTemplate = str_replace('[CONTENT]', $emailBody, $emailTemplate);
                        
                        $email = new TransactionalEmail();
                        $email->to_name   = $user->getFullName();
                        $email->to_email  = $user->email;
                        $email->from_name = Yii::t('ext_support_tickets', '{site} support', array('{site}' => $options->get('system.common.site_name', 'Marketing website')));
                        $email->subject   = Yii::t('ext_support_tickets', '[{site} support] {subject}', array(
                            '{site}'    => $options->get('system.common.site_name', 'Marketing website'),
                            '{subject}' => $ticket->subject,
                        ));
                        $email->body      = $emailTemplate;
                        $email->save();
                    }    
                }
            }
            
            Yii::app()->hooks->doAction('controller_action_save_data', $collection = new CAttributeCollection(array(
                'controller'=> $this,
                'success'   => $notify->hasSuccess,
                'ticket'    => $ticket,
                'reply'     => $reply,
            )));
            
            if ($collection->success) {
                $this->redirect($this->createUrl($this->id . '/view', array('id' => $ticket->ticket_id)) . '#reply-' . $reply->reply_id);
            }
        }
        
        $reply->fieldDecorator->onHtmlOptionsSetup = array($this, '_setupEditorOptions');
        
        $this->setData(array(
            'pageMetaTitle'   => $this->data->pageMetaTitle . ' | '. Yii::t('ext_support_tickets', 'View support ticket'),
            'pageHeading'     => Yii::t('ext_support_tickets', 'View support ticket'),
            'pageBreadcrumbs' => array(
                Yii::t('ext_support_tickets', 'Support tickets')  => $this->createUrl($this->id . '/index'),
                sprintf('#%d', $id)  => $this->createUrl($this->id . '/update', array('id' => $id)),
                Yii::t('app', 'View'),
            )
        ));

        $this->render('view', compact('ticket', 'reply'));
    }
    
    public function actionRate_reply($ticket_id, $reply_id, $rating)
    {
        $request = Yii::app()->request;
        if (!$request->isAjaxRequest) {
            $this->redirect(array($this->id . '/index'));
        }
        
        $ticket = SupportTicket::model()->findByAttributes(array(
            'ticket_id'   => (int)$ticket_id, 
            'customer_id' => Yii::app()->customer->getId()
        ));
        if (empty($ticket)) {
            return $this->renderJson(array(
                'result'  => 'error',
                'message' => Yii::t('app', 'The requested page does not exist.'),
            ));
        }
        
        $reply = SupportTicketReply::model()->findByAttributes(array(
            'reply_id'  => (int)$reply_id,
            'ticket_id' => (int)$ticket_id,
        ));
        if (empty($reply)) {
            return $this->renderJson(array(
                'result'  => 'error',
                'message' => Yii::t('app', 'The requested page does not exist.'),
            ));
        }
        
        if (!$reply->getCanBeRated()) {
            return $this->renderJson(array(
                'result'  => 'error',
                'message' => Yii::t('ext_support_tickets', 'This reply cannot be rated anymore.'),
            ));
        }
        
        $reply->rating = (int)$rating;
        if (!$reply->save()) {
            return $this->renderJson(array(
                'result'  => 'error',
                'message' => $reply->shortErrors->getAllAsString(),
            ));
        }

        return $this->renderJson(array(
            'result'  => 'success',
            'message' => Yii::t('ext_support_tickets', 'Thank you, your rating has been successfully applied.'),
        ));
    }
    
    /**
     * Callback to register assets
     */
    public function _handleAssetsRegistration($event)
    {
        if (in_array($event->params['action']->id, array('view'))) {
            $commonAssetsUrl = Yii::app()->assetManager->publish(Yii::getPathOfAlias('ext-support-tickets.common.assets'), false, -1, MW_DEBUG);
            $assetsUrl       = Yii::app()->assetManager->publish(Yii::getPathOfAlias('ext-support-tickets.customer.assets'), false, -1, MW_DEBUG);
            $this->getData('pageStyles')->mergeWith(array(
                array('src' => $commonAssetsUrl . '/css/support-tickets.css'),
            ));
            $this->getData('pageScripts')->mergeWith(array(
                array('src' => $assetsUrl . '/js/support-tickets.js'),
            ));
        }
    }
    
    /**
     * Callback method to set the editor options
     */
    public function _setupEditorOptions(CEvent $event)
    {
        if (!in_array($event->params['attribute'], array('content'))) {
            return;
        }
        
        $options = array();
        if ($event->params['htmlOptions']->contains('wysiwyg_editor_options')) {
            $options = (array)$event->params['htmlOptions']->itemAt('wysiwyg_editor_options');
        }
        $options['id']     = CHtml::activeId($event->sender->owner, $event->params['attribute']);
        $options['height'] = 400;
        
        if ($event->sender->owner instanceof SupportTicketReply) {
            $options['height'] = 200;
        }
        
        $event->params['htmlOptions']->add('wysiwyg_editor_options', $options);
    }
}